==> rong-ui-react-0.0.1.tgz: package/es/switch/switch.js <==
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import { memo, useEffect, useState, useRef } from "react";
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import './style/switch.less';
var prefixCls = 'r-switch';

var Switch = function Switch(_ref) {
  var checked = _ref.checked,
      disabled = _ref.disabled,
      checkedChildren = _ref.checkedChildren,
      unCheckedChildren = _ref.unCheckedChildren,
      onChange = _ref.onChange;

  var _useState = useState(checked),
      _useState2 = _slicedToArray(_useState, 2),
      onOff = _useState2[0],
      setOnOff = _useState2[1];

  var _useState3 = useState(),
      _useState4 = _slicedToArray(_useState3, 2),
      maxLeft = _useState4[0],
      setMaxLeft = _useState4[1];

  var switchRef = useRef();
  var circleRef = useRef();
  console.log('Switch mounted or updated');
  useEffect(function () {
    setOnOff(checked);
  }, [checked]);
  useEffect(function () {
    setMaxLeft(switchRef.current.offsetWidth - circleRef.current.offsetWidth - 3);
  }, []);
  var wrapCls = classNames([prefixCls, _defineProperty({}, "".concat(prefixCls, "-checked"), onOff)]);
  var innerCls = "".concat(prefixCls, "-inner");
  var circleStyle = {
    left: onOff ? maxLeft + 'px' : ''
  };

  var onSwitchClick = function onSwitchClick(e) {
    if (disabled) return;
    var tempOnOff = !onOff;
    setOnOff(tempOnOff);
    onChange && onChange(tempOnOff);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    ref: switchRef,
    onClick: onSwitchClick
  }, /*#__PURE__*/React.createElement("div", {
    className: innerCls
  }, /*#__PURE__*/React.createElement("div", {
    className: "open"
  }, checkedChildren), /*#__PURE__*/React.createElement("div", {
    className: "close"
  }, unCheckedChildren)), /*#__PURE__*/React.createElement("div", {
    className: "circle",
    ref: circleRef,
    style: circleStyle
  }));
};

setDefaultProps(Switch, {
  checked: {
    type: PropTypes.bool,
    default: false
  },
  disabled: {
    type: PropTypes.bool
  },
  checkedChildren: {
    type: PropTypes.node
  },
  unCheckedChildren: {
    type: PropTypes.node
  },
  onChange: {
    type: PropTypes.func
  }
});
export default /*#__PURE__*/memo(Switch);

==> rong-ui-react-0.0.5.tgz: package/es/switch/switch.js <==
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import { memo, useEffect, useState, useRef } from "react";
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
var prefixCls = 'r-switch';

var Switch = function Switch(_ref) {
  var defaultChecked = _ref.defaultChecked,
      disabled = _ref.disabled,
      checkedChildren = _ref.checkedChildren,
      unCheckedChildren = _ref.unCheckedChildren,
      onChange = _ref.onChange;

  var _useState = useState(defaultChecked),
      _useState2 = _slicedToArray(_useState, 2),
      onOff = _useState2[0],
      setOnOff = _useState2[1];

  var _useState3 = useState(),
      _useState4 = _slicedToArray(_useState3, 2),
      maxLeft = _useState4[0],
      setMaxLeft = _useState4[1];

  var switchRef = useRef();
  var circleRef = useRef();
  console.log('Switch mounted or updated');
  useEffect(function () {
    setOnOff(defaultChecked);
  }, [defaultChecked]);
  useEffect(function () {
    setMaxLeft(switchRef.current.offsetWidth - circleRef.current.offsetWidth - 3);
  }, []);
  var wrapCls = classNames([prefixCls, _defineProperty({}, "".concat(prefixCls, "-checked"), onOff)]);
  var innerCls = "".concat(prefixCls, "-inner");
  var circleStyle = {
    left: onOff ? maxLeft + 'px' : ''
  };

  var onSwitchClick = function onSwitchClick(e) {
    if (disabled) return;
    var tempOnOff = !onOff;
    setOnOff(tempOnOff);
    onChange && onChange(tempOnOff, e);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    ref: switchRef,
    onClick: onSwitchClick
  }, /*#__PURE__*/React.createElement("div", {
    className: innerCls
  }, /*#__PURE__*/React.createElement("div", {
    className: "open"
  }, checkedChildren), /*#__PURE__*/React.createElement("div", {
    className: "close"
  }, unCheckedChildren)), /*#__PURE__*/React.createElement("div", {
    className: "circle",
    ref: circleRef,
    style: circleStyle
  }));
};

setDefaultProps(Switch, {
  defaultChecked: {
    type: PropTypes.bool,
    default: false
  },
  disabled: {
    type: PropTypes.bool
  },
  checkedChildren: {
    type: PropTypes.node
  },
  unCheckedChildren: {
    type: PropTypes.node
  },
  onChange: {
    type: PropTypes.func
  }
});
export default /*#__PURE__*/memo(Switch);
